<?php
echo'<div id="header"><a href="http://'.$_SERVER['SERVER_NAME'].'">
		<img id="fotoheader" alt="'.$_SERVER['SERVER_NAME'].'" title="'.$_SERVER['SERVER_NAME'].'" src="http://'.$_SERVER['SERVER_NAME'].'/img/drapel-giurgiu.jpg" />
	</a></div>';
		
?>